@@ -1061,6 +1061,11 @@ simdevVisit(dev, hierName, trans)
         sprintf(name, "fet");
         simdevOutNode(hierName, subnode->efnode_name->efnn_hier, name, esSimF); 
     }
+    else if (dev->dev_class == DEV_DIODE && dev->dev_nterm == 1 && subnode)
+    {
+	sprintf(name, "fet");
+	simdevOutNode(hierName, subnode->efnode_name->efnn_hier, name, esSimF);
+    }
     else if (dev->dev_nterm > 2)
         simdevOutNode(hierName, drain->dterm_node->efnode_name->efnn_hier, name, esSimF);
 
