@@ -1590,6 +1590,13 @@ spcdevVisit(dev, hierName, trans)
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
 	    break;
+	case DEV_DIODE:
+	    if ((dev->dev_nterm < 2) && (subnode == NULL))
+	    {
+		TxError("Diode has only one terminal\n");
+		return 0;
+	    }
+	    break;
 	default:
 	    if (dev->dev_nterm < 2)
 	    {
@@ -1613,6 +1620,8 @@ spcdevVisit(dev, hierName, trans)
     {
 	case DEV_RES:
 	case DEV_CAP:
+	    if (dev->dev_nterm < 1)
+		return 0;
 	    if (dev->dev_type == esNoModelType)
 		has_model = FALSE;
 	    break;
@@ -1874,7 +1883,11 @@ spcdevVisit(dev, hierName, trans)
 
 	    spcdevOutNode(hierName, gate->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
-	    spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
+	    if (dev->dev_nterm > 1)
+		spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
+			name, esSpiceF);
+	    else
+		spcdevOutNode(hierName, subnode->efnode_name->efnn_hier,
 			name, esSpiceF);
 	    fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
 	    break;
