@@ -46,7 +46,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/
 #include "utils/main.h"
 #include "select/select.h"
 
-#if defined(SYSV) || defined(macosx)
+#if defined(SYSV) || defined(__APPLE__)
 # define	NO_RUSAGE
 #endif
 
@@ -155,6 +155,7 @@ PlowRule *plowBuildWidthRules();
 void plowMergeBottom(Tile *, Plane *);
 void plowInitRule();
 
+extern void PlowExtendJogHorizon();
 extern void PlowRedrawBound();
 extern void PlowClearBound();
 extern void plowUpdate();
@@ -1171,7 +1172,7 @@ plowFindSelCell(yankUse, editUse)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 PlowExtendJogHorizon(edge)
     Edge *edge;			/* Edge being moved */
 {
@@ -1707,6 +1708,7 @@ plowApplySearchRules(edge)
 	    (*rte->rte_proc)(edge, rules);
 	}
     }
+    return 0;
 }
 
 /*
